Skip to contents

Returns one row per scale with alpha and omega estimates.

Usage

# S3 method for class 'sframe_reliability_report'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)

Arguments

x

A surveyframe object.

row.names

Passed to base::as.data.frame() by the methods that build a frame. Ignored by the methods that return a stored table.

optional

Passed to base::as.data.frame().

...

Ignored. Present for S3 consistency.

Value

A data frame of scale reliability statistics.