Returns the rules that control whether conditional items are shown.
Value
An sf_component_list of branching rules.
Examples
sf_branches(sframe_demo_data()$instrument)
#> <branch rule list: 0>
Returns the rules that control whether conditional items are shown.
An sf_component_list of branching rules.
sf_branches(sframe_demo_data()$instrument)
#> <branch rule list: 0>