Skip to contents

Returns the scale definitions, including their item membership and scoring settings.

Usage

sf_scales(x, ...)

Arguments

x

A surveyframe object.

...

Passed to methods.

Value

An sf_component_list for an instrument or a scale data frame for a codebook.

See also

Examples

sf_scales(sframe_demo_data()$instrument)
#> <scale list: 5>
#>  <sf_scale: digital_marketing | 3 item(s)>
#>  <sf_scale: service_quality | 3 item(s)>
#>  <sf_scale: sustainability | 2 item(s)>
#>  <sf_scale: satisfaction | 2 item(s)>
#>  <sf_scale: behavioural_intention | 2 item(s)>