Add a model specification to an instrument
Arguments
- instrument
An
sframeobject.- model
An
sf_model()object.- validate
Logical. Whether to validate the model against the instrument before adding it.
- replace
Logical. Whether to replace an existing model with the same ID. Defaults to
TRUE.