add_model: Add a model specification to an instrument

View source: R/model_layer.R

add_modelR Documentation

Add a model specification to an instrument

Description

Add a model specification to an instrument

Usage

add_model(instrument, model, validate = TRUE, replace = TRUE)

Arguments

instrument

An sframe object.

model

An sf_model() object.

validate

Logical. Whether to validate the model against the instrument before adding it.

replace

Logical. Whether to replace an existing model with the same ID. Defaults to TRUE.

Value

The updated sframe object.


surveyframe documentation built on July 25, 2026, 1:07 a.m.