| add_model | R Documentation |
Add a model specification to an instrument
add_model(instrument, model, validate = TRUE, replace = TRUE)
instrument |
An |
model |
An |
validate |
Logical. Whether to validate the model against the instrument before adding it. |
replace |
Logical. Whether to replace an existing model with the same
ID. Defaults to |
The updated sframe object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.