View source: R/statistics_reports.R
| descriptives_report | R Documentation |
Computes survey descriptives for numeric, Likert, and scale-score columns, including missingness, mean, standard deviation, median, IQR, range, skewness, kurtosis, standard error, and confidence intervals.
descriptives_report(
data,
variables = NULL,
split_by = NULL,
conf_level = 0.95,
weights = NULL
)
data |
A data.frame of responses. |
variables |
Character vector of variables. When |
split_by |
Optional grouping variable. |
conf_level |
Confidence level for the mean interval. |
weights |
Optional case-weight column. |
An object of class sframe_descriptives_report.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.