View source: R/psychometrics.R
| item_report | R Documentation |
Produces item-total correlations, floor and ceiling effect proportions, and item means and standard deviations for each item within each scale.
item_report(data, instrument, scales = NULL)
data |
A |
instrument |
An |
scales |
Character vector or NULL. A subset of scale IDs to analyse. When NULL (default), all scales are included. |
An object of class sframe_item_report, a list with one data.frame
per scale.
reliability_report(), sf_scale()
demo <- sframe_demo_data()
ir <- item_report(demo$responses, demo$instrument)
print(ir)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.