View source: R/statistics_reports.R
| missing_data_report | R Documentation |
Reports item-wise missingness, respondent-wise missingness, missing-data patterns, listwise and pairwise deletion counts, and scale scoring missing rules. No imputation is performed.
missing_data_report(data, instrument = NULL, variables = NULL)
data |
A data.frame of responses. |
instrument |
Optional |
variables |
Optional response columns. Defaults to instrument item IDs when an instrument is supplied, otherwise all columns. |
An object of class sframe_missing_data_report.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.