| sframe_plot_correlation_matrix | R Documentation |
Computes and plots a full pairwise correlation matrix, independent of
run_analysis_plan()'s pairwise correlation_pearson/_spearman/
_kendall runners (which plot one variable pair at a time via
sframe_plot_correlation()). Useful directly, and as the visual
companion to validity_report()'s discriminant-validity checks.
sframe_plot_correlation_matrix(
data,
vars,
method = "pearson",
palette = c("web", "print")
)
data |
A data frame of survey responses. |
vars |
Character vector of column names to correlate. |
method |
One of |
palette |
One of |
A ggplot2 object.
validity_report()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.