Checks model IDs, construct IDs, indicators, structural path endpoints, duplicate paths, indirect paths, and engine/type compatibility.
Arguments
- model
An
sf_model()object or compatible list.- instrument
Optional
sframeobject. When supplied, model indicators must match instrument item IDs.- strict
Logical. When
TRUE, invalid models raise an error. WhenFALSE, a list withvalidandproblemsis returned.